package org.nakedobjects.applib.fixtures;

import java.util.List;
import java.util.Vector;


/**
 * Convenience class for creating fixtures.
 * <p>
 * Also makes it easy to change the date/time within the course of a fixture installation (via the service
 * property).
 */
public abstract class AbstractFixture {
    private Vector<Object> fixtures = new Vector<Object>();
    protected FixtureServices service;
    protected FixtureFactoryAndRepository repository;

    /**
     * Subclasses need only override this method.
     */
    public abstract void install();

    /**
     * Allows the fixture to act as a composite.
     */
    protected void addFixture(final Object fixture) {
        fixtures.add(fixture);
    }

    /**
     * Returns an array of any fixtures that have been {@link #addFixture(Object) added}.
     */
    public Object[] getFixtures() {
        return fixtures.toArray();
    }

    public void setService(final FixtureServices fixtureService) {
        this.service = fixtureService;
    }

    public void setService(final FixtureFactoryAndRepository fixtureRepository) {
        this.repository = fixtureRepository;
    }

    /**
     * Save the specified object to the persistent object store.
     */
    protected void makePersistent(final Object object) {
        repository.makePersistent(object);
    }

    protected <T> T newTransientInstance(final Class<T> ofClass) {
        return repository.newTransientInstance(ofClass);
    }
    
    protected <T> List<T> allInstances(final Class<T> cls, final boolean includeSubclasses) {
        return repository.allInstances(cls, includeSubclasses);
    }

    protected void setTime(final int hour, final int minute) {
        service.setTime(hour, minute);
    }

    protected void setDate(final int year, final int month, final int day) {
        service.setDate(year, month, day);
    }

    protected void setUser(final String username) {
        service.setUser(username, null);
    }

    protected void setUser(final String username, final String[] roles) {
        service.setUser(username, roles);
    }
}
